(function ($, Drupal, drupalSettings, once) {
  'use strict';

  Drupal.behaviors.contentSaveConfirm = {
    attach: function (context, settings) {
      // Debug: Check if settings are available
      if (typeof drupalSettings.contentSaveConfirm === 'undefined') {
        console.log('Content Save Confirm: Settings not found');
        return;
      }

      // Add CSS for the modal dialog if not already added
      if (!$('#content-save-confirm-styles').length) {
        var styles = `
          <style id="content-save-confirm-styles">
            .content-save-confirm-overlay {
              position: fixed;
              top: 0;
              left: 0;
              width: 100%;
              height: 100%;
              background: rgba(0, 0, 0, 0.6);
              z-index: 9999;
              display: flex;
              align-items: center;
              justify-content: center;
              backdrop-filter: blur(3px);
            }
            
            .content-save-confirm-dialog {
              background: white;
              border-radius: 8px;
              padding: 24px;
              max-width: 480px;
              width: 90%;
              box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
              animation: content-save-confirm-fade-in 0.2s ease-out;
              position: relative;
            }
            
            @keyframes content-save-confirm-fade-in {
              from {
                opacity: 0;
                transform: scale(0.95) translateY(-10px);
              }
              to {
                opacity: 1;
                transform: scale(1) translateY(0);
              }
            }
            
            .content-save-confirm-header {
              display: flex;
              align-items: center;
              margin-bottom: 16px;
            }
            
            .content-save-confirm-icon {
              width: 24px;
              height: 24px;
              margin-right: 12px;
              color: #f59e0b;
              flex-shrink: 0;
            }
            
            .content-save-confirm-title {
              font-size: 18px;
              font-weight: 600;
              color: #1f2937;
              margin: 0;
            }
            
            .content-save-confirm-message {
              color: #4b5563;
              line-height: 1.5;
              margin-bottom: 24px;
              font-size: 14px;
            }
            
            .content-save-confirm-buttons {
              display: flex;
              gap: 12px;
              justify-content: flex-end;
            }
            
            .content-save-confirm-btn {
              padding: 8px 16px;
              border-radius: 6px;
              font-size: 14px;
              font-weight: 500;
              cursor: pointer;
              border: 1px solid;
              transition: all 0.2s;
              min-width: 80px;
            }
            
            .content-save-confirm-btn-cancel {
              background: white;
              color: #6b7280;
              border-color: #d1d5db;
            }
            
            .content-save-confirm-btn-cancel:hover {
              background: #f9fafb;
              border-color: #9ca3af;
            }
            
            .content-save-confirm-btn-confirm {
              background: #3b82f6;
              color: white;
              border-color: #3b82f6;
            }
            
            .content-save-confirm-btn-confirm:hover {
              background: #2563eb;
              border-color: #2563eb;
            }
            
            .content-save-confirm-btn:focus {
              outline: 2px solid #3b82f6;
              outline-offset: 2px;
            }
          </style>
        `;
        $('head').append(styles);
      }

      // Function to create and show custom confirmation dialog
      function showConfirmDialog(message, title) {
        return new Promise(function(resolve) {
          // Create dialog HTML
          var dialogHtml = `
            <div class="content-save-confirm-overlay">
              <div class="content-save-confirm-dialog">
                <div class="content-save-confirm-header">
                  <svg class="content-save-confirm-icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-2.5L13.732 4c-.77-.833-1.964-.833-2.732 0L4.082 16.5c-.77.833.192 2.5 1.732 2.5z"></path>
                  </svg>
                  <h3 class="content-save-confirm-title">${title || 'Confirm Action'}</h3>
                </div>
                <div class="content-save-confirm-message">${message}</div>
                <div class="content-save-confirm-buttons">
                  <button type="button" class="content-save-confirm-btn content-save-confirm-btn-cancel">Cancel</button>
                  <button type="button" class="content-save-confirm-btn content-save-confirm-btn-confirm">Confirm</button>
                </div>
              </div>
            </div>
          `;
          
          // Add dialog to page
          var $dialog = $(dialogHtml);
          $('body').append($dialog);
          
          // Focus the confirm button
          setTimeout(function() {
            $dialog.find('.content-save-confirm-btn-confirm').focus();
          }, 100);
          
          // Handle button clicks
          $dialog.find('.content-save-confirm-btn-cancel').on('click', function() {
            $dialog.remove();
            resolve(false);
          });
          
          $dialog.find('.content-save-confirm-btn-confirm').on('click', function() {
            $dialog.remove();
            resolve(true);
          });
          
          // Handle overlay click (cancel)
          $dialog.on('click', function(e) {
            if (e.target === this) {
              $dialog.remove();
              resolve(false);
            }
          });
          
          // Handle escape key
          $(document).on('keydown.content-save-confirm', function(e) {
            if (e.keyCode === 27) { // Escape key
              $(document).off('keydown.content-save-confirm');
              $dialog.remove();
              resolve(false);
            }
          });
        });
      }

      // Find forms with the content-save-confirm-form class using once
      once('content-save-confirm', '.content-save-confirm-form', context).forEach(function (form) {
        var $form = $(form);
        var confirmSettings = drupalSettings.contentSaveConfirm;
        
        console.log('Content Save Confirm: Attaching to form', $form.attr('id'));
        console.log('Content Save Confirm: Settings', confirmSettings);
        
        // Find submit buttons - be more specific about which buttons to target
        var $submitButtons = $form.find('input[type="submit"], button[type="submit"]');
        
        console.log('Content Save Confirm: Found buttons', $submitButtons.length);
        
        // Add click handler to submit buttons
        $submitButtons.each(function() {
          var $button = $(this);
          var buttonValue = $button.val() || $button.text() || $button.attr('data-drupal-selector') || '';
          
          console.log('Content Save Confirm: Button found', buttonValue);
          
          // Skip confirmation for certain buttons (like preview, delete, etc.)
          var skipConfirmation = /preview|delete|cancel|remove|draft/i.test(buttonValue);
          
          if (!skipConfirmation) {
            console.log('Content Save Confirm: Adding handler to button', buttonValue);
            
            $button.on('click.content-save-confirm', function (e) {
              console.log('Content Save Confirm: Button clicked', buttonValue);
              
              // Prevent default form submission
              e.preventDefault();
              e.stopImmediatePropagation();
              
              // Show custom confirmation dialog
              var title = confirmSettings.title || 'Confirm Save';
              var message = confirmSettings.message || 'Are you sure you want to save these changes?';
              
              showConfirmDialog(message, title).then(function(confirmed) {
                console.log('Content Save Confirm: User confirmed?', confirmed);
                
                if (confirmed) {
                  // If confirmed, remove our handler and submit
                  $button.off('click.content-save-confirm');
                  
                  // Create a new click event to trigger original handlers
                  var clickEvent = new MouseEvent('click', {
                    bubbles: true,
                    cancelable: true,
                    view: window
                  });
                  
                  // Dispatch the event to trigger form submission
                  $button[0].dispatchEvent(clickEvent);
                }
              });
              
              return false;
            });
          }
        });
      });
    }
  };

})(jQuery, Drupal, drupalSettings, once);